==> ktp-accounts-kcm-22.08.0.tar.xz: ktp-accounts-kcm-22.08.0/plugins/sipe/ktpaccountskcm_plugin_sipe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the sipe connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći sipzmenadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Sipe.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalitzat per a comptes que utilitzen el gestor de connexions Sipe.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení sipe.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen sipe.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Sipe-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων sipe.
Comment[en_GB]=Custom account configuration user interface for accounts using the sipe connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones sipe.
Comment[et]=Sipe ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «sipe» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Sipe-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « sipe ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Sipe.
Comment[hu]=Egyedi beállítófelület a sipe kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Sipe.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Sipe.
Comment[ko]=sipe 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant sipe ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av sipe tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „sipe“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Sipe verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med SIPE tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń sipe.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Sipe.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Sipe.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Sipe.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью диспетчера соединений Sipe.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Sipe.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Sipe.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Sipe.
Comment[tr]=Sipe bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями sipe.
Comment[x-test]=xxCustom account configuration user interface for accounts using the sipe connection manager.xx
Comment[zh_CN]=通过 sipe 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 sipe 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Sipe Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Sipe
Name[ca]=Interfície d'usuari de configuració del compte de Sipe
Name[ca@valencia]=Interfície d'usuari de configuració del compte de Sipe
Name[cs]=Uživatelské rozhraní nastavení účtu Sipe
Name[da]=Brugerflade til konfiguration af sipe-konto
Name[de]=Benutzeroberfläche zur Einrichtung von Sipe-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη Sipe
Name[en_GB]=Sipe Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Sipe
Name[et]=Sipe konto seadistamise kasutajaliides
Name[eu]=«Sipe» kontuak konfiguratzeko erabiltzaile interfazea
Name[fi]=Sipe-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « sipe ».
Name[gl]=Interface de usuario para a configuración de contas de Sipe
Name[hu]=Sipe azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Sipe
Name[it]=Interfaccia utente di configurazione account Sipe
Name[ko]=Sipe 계정 설정 사용자 인터페이스
Name[lt]=Sipe paskyros konfigūravimo naudotojo sąsaja
Name[nb]=Brukerflate for å sette opp Sipe-konto
Name[nds]=Sipe-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Sipe accountconfiguratie
Name[nn]=Brukarflate for å setja opp SIPE-konto
Name[pl]=Nakładka graficzna do ustawiania konta Sipe
Name[pt]=Interface de Configuração de Contas do Sipe
Name[pt_BR]=Interface de configuração de contas do Sipe
Name[ro]=Interfață de configurare a conturilor Sipe
Name[ru]=Интерфейс для настройки учётной записи Sipe
Name[sk]=Používateľské rozhranie konfigurácie účtu Sipe
Name[sl]=Uporabniški vmesnik za nastavitev računov Sipe
Name[sr]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sv]=Användargränssnitt för inställning av Sipe-konton
Name[tr]=Sipe Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштовування sipe
Name[x-test]=xxSipe Account Configuration User Interfacexx
Name[zh_CN]=Sipe 账户用户配置界面
Name[zh_TW]=Sipe 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_sipe
X-KDE-PluginInfo-Author=Maksim Melnikau
X-KDE-PluginInfo-Email=maxposedon@gmail.com
X-KDE-PluginInfo-Name=sipe
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true

==> ktp-accounts-kcm_22.12.3.orig.tar.xz: ktp-accounts-kcm-22.12.3/plugins/sipe/ktpaccountskcm_plugin_sipe.desktop.cmake <==
[Desktop Entry]
Encoding=UTF-8
Comment=Custom account configuration user interface for accounts using the sipe connection manager.
Comment[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga koristeći sipzmenadžer konekcja.
Comment[ca]=Interfície d'usuari de configuració del compte personalitzat per a comptes que usen el gestor de connexions Sipe.
Comment[ca@valencia]=Interfície d'usuari de configuració del compte personalitzat per a comptes que utilitzen el gestor de connexions Sipe.
Comment[cs]=Vlastní uživatelské rozhraní nastavení účtů pro účty používající správce spojení sipe.
Comment[da]=Brugerflade til brugertilpasset kontokonfiguration til konti der bruger forbindelseshåndteringen sipe.
Comment[de]=Eigene Benutzeroberfläche zum Einrichten von Zugängen, die die Sipe-Verbindungsverwaltung verwenden.
Comment[el]=Περιβάλλον προσαρμοσμένης διαμόρφωσης λογαριασμού χρήστη για λογαριασμούς που χρησιμοποιούν το διαχειριστή συνδέσεων sipe.
Comment[en_GB]=Custom account configuration user interface for accounts using the sipe connection manager.
Comment[es]=Interfaz de configuración de cuentas personalizadas para las cuentas que usen el gestor de conexiones sipe.
Comment[et]=Sipe ühendusehaldurit kasutavate kontode kohandatud konto seadistamise kasutajaliides
Comment[eu]=Kontuak konfiguratzeko norberak finkaturiko erabiltzaile interfazea «sipe» konexio kudeatzailea erabiltzen duten kontuetarako.
Comment[fi]=Sipe-yhteyshallintaa käyttävien tilien mukautettu hallintakäyttöliittymä.
Comment[fr]=Interface utilisateur personnalisée pour la configuration de comptes en utilisant le gestionnaire de connexions « sipe ».
Comment[gl]=Interface de usuario de configuración personalizada da conta para contas que empreguen o xestor de conexións Sipe.
Comment[hu]=Egyedi beállítófelület a sipe kapcsolatkezelőt használó azonosítókhoz.
Comment[ia]=Interfacie de usator pro configuration de conto personalisate pro contos usante le gerente de connexion Sipe.
Comment[it]=Interfaccia utente personalizzata di configurazione account per account che usano il gestore di connessioni Sipe.
Comment[ka]=ხელით მითითებული ანგარიშის მორგების მომხმარებლის ინტერფეისი sipe -ის შეერთების მმართველის გამოყენებით.
Comment[ko]=sipe 연결 관리자를 사용하는 계정 설정 사용자 인터페이스입니다.
Comment[lt]=Savito paskyros konfigūravimo naudotojo sąsaja paskyroms naudojant sipe ryšio tvarkyklę.
Comment[nb]=Brukerflate for å sette opp egendefinerte kontoer ved bruk av sipe tilkoblingsbehandler.
Comment[nds]=Topasst Kontoinstellen-Böversiet för Kontos, de den Verbinnenpleger „sipe“ bruukt
Comment[nl]=Gebruikersinterface voor aangepaste accountconfiguratie voor accounts die de Sipe verbindingenbeheerder gebruiken.
Comment[nn]=Brukarflate for å setja oppkontoar med SIPE tilkoplingshandsamar.
Comment[pl]=Dostosowana nakładka graficzna do ustawiania kont dla kont wykorzystujących usługę połączeń sipe.
Comment[pt]=Interface de utilizador de configuração de contas personalizadas com o gestor de ligações Sipe.
Comment[pt_BR]=Interface de configuração de contas usando o gerenciador de conexões Sipe.
Comment[ro]=Interfață personalizată de configurare a conturilor folosind gestionarul de conexiuni Sipe.
Comment[ru]=Пользовательский интерфейс для настройки учётной записи с помощью диспетчера соединений Sipe.
Comment[sk]=Vlastné používateľské rozhranie konfigurácie účtu pre účty používajúce správcu pripojení Sipe.
Comment[sl]=Uporabniški vmesnik za prilagoditev računov, ki uporabljajo upravljalnik povezav Sipe.
Comment[sr]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavian]=Корисничко сучеље за подешавање посебних налога под менаџером везе Сајп.
Comment[sr@ijekavianlatin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sr@latin]=Korisničko sučelje za podešavanje posebnih naloga pod menadžerom veze SIPE.
Comment[sv]=Användargränssnitt för anpassad kontoinställning av konton som använder anslutningshanteraren Sipe.
Comment[tr]=Sipe bağlantı yöneticisi kullanan hesaplar için özel hesap yapılandırma kullanıcı arayüzü
Comment[uk]=Інтерфейс користувача для нетипового налаштовування облікового запису за допомогою керування з’єднаннями sipe.
Comment[x-test]=xxCustom account configuration user interface for accounts using the sipe connection manager.xx
Comment[zh_CN]=通过 sipe 连接管理器自定义账户的配置界面
Comment[zh_TW]=對使用 sipe 連線管理員的帳號自訂帳號設定使用者介面。
Icon=blockdevice
Name=Sipe Account Configuration User Interface
Name[bs]=Korisnički interfejs za konfiguraciju korisničkih naloga Sipe
Name[ca]=Interfície d'usuari de configuració del compte de Sipe
Name[ca@valencia]=Interfície d'usuari de configuració del compte de Sipe
Name[cs]=Uživatelské rozhraní nastavení účtu Sipe
Name[da]=Brugerflade til konfiguration af sipe-konto
Name[de]=Benutzeroberfläche zur Einrichtung von Sipe-Zugängen
Name[el]=Περιβάλλον διαμόρφωσης λογαριασμού χρήστη Sipe
Name[en_GB]=Sipe Account Configuration User Interface
Name[es]=Interfaz de configuración de cuentas Sipe
Name[et]=Sipe konto seadistamise kasutajaliides
Name[eu]=«Sipe» kontuak konfiguratzeko erabiltzaile interfazea
Name[fi]=Sipe-tilinmäärityksen käyttöliittymä
Name[fr]=Interface utilisateur pour la configuration de comptes « sipe ».
Name[gl]=Interface de usuario para a configuración de contas de Sipe
Name[hu]=Sipe azonosítóbeállító felület
Name[ia]=Interfacie de usator de configuration de conto de Sipe
Name[it]=Interfaccia utente di configurazione account Sipe
Name[ka]=Sipe -ის ანგარიშის მორგების ინტერფეისი
Name[ko]=Sipe 계정 설정 사용자 인터페이스
Name[lt]=Sipe paskyros konfigūravimo naudotojo sąsaja
Name[nb]=Brukerflate for å sette opp Sipe-konto
Name[nds]=Sipe-Kontoinstellenböversiet
Name[nl]=Gebruikersinterface voor Sipe accountconfiguratie
Name[nn]=Brukarflate for å setja opp SIPE-konto
Name[pl]=Nakładka graficzna do ustawiania konta Sipe
Name[pt]=Interface de Configuração de Contas do Sipe
Name[pt_BR]=Interface de configuração de contas do Sipe
Name[ro]=Interfață de configurare a conturilor Sipe
Name[ru]=Интерфейс для настройки учётной записи Sipe
Name[sk]=Používateľské rozhranie konfigurácie účtu Sipe
Name[sl]=Uporabniški vmesnik za nastavitev računov Sipe
Name[sr]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavian]=Корисничко сучеље за подешавање налога под Сајпом
Name[sr@ijekavianlatin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sr@latin]=Korisničko sučelje za podešavanje naloga pod SIPE‑om
Name[sv]=Användargränssnitt för inställning av Sipe-konton
Name[tr]=Sipe Hesap Yapılandırma Kullanıcı Arayüzü
Name[uk]=Інтерфейс користувача для налаштовування sipe
Name[x-test]=xxSipe Account Configuration User Interfacexx
Name[zh_CN]=Sipe 账户用户配置界面
Name[zh_TW]=Sipe 帳號設定使用者介面
Type=Service
ServiceTypes=KTpAccountsKCM/AccountUiPlugin

X-KDE-Library=ktpaccountskcm_plugin_sipe
X-KDE-PluginInfo-Author=Maksim Melnikau
X-KDE-PluginInfo-Email=maxposedon@gmail.com
X-KDE-PluginInfo-Name=sipe
X-KDE-PluginInfo-Version=@KTP_ACCOUNTS_KCM_VERSION@
X-KDE-PluginInfo-Website=http://techbase.kde.org/Projects/Telepathy
X-KDE-PluginInfo-License=LGPL
X-KDE-PluginInfo-EnabledByDefault=true
